@@ -4,7 +4,6 @@ using dask tasks and parallelizing multiple games in PGNs
 """
 import os
 import errno
-import json
 import base64
 import yaml
 from dask.distributed import LocalCluster
@@ -14,8 +13,7 @@ from dask.distributed import TimeoutError
 from distributed import wait
 from dask import config
 import coiled
-from .chess_util import ChessUtil
-from .chess_image_generator import ChessImageGenerator
+from chess_util import ChessUtil
 
 
 class ChessDaskCluster:
@@ -126,11 +124,10 @@ class ChessDaskCluster:
 
         self.client = Client(cluster)
 
-    def analyse_games_in_cluster(self, game_list):
+    def analyse_games_in_cluster(self, game_list, handler):
         "Find control heatmap for all the games passed, in parallel in a dask cluster"
         game_no = 0
         game_futures = []
-        all_game_results = []
         game_master_list = []
         timeout = self.config_values["timeout_per_game"]
         for game in game_list:
@@ -141,24 +138,15 @@ class ChessDaskCluster:
         for game in game_master_list:
             batch.append(game)
             if index % self.config_values["game_batch_size"] == 0:
-                game_futures = self.client.map(ChessDaskCluster.analyse_game_in_worker, batch)
-                all_game_results.extend(self.client.gather(game_futures))
+                self.submit_batch_to_worker(batch, handler)
                 batch = []
                 print("Completed games till " + str(index))
             index = index + 1
         if batch:
-            game_futures = self.client.map(ChessDaskCluster.analyse_game_in_worker, batch)
-            all_game_results.extend(self.client.gather(game_futures))
-        
-        if self.config_values["debug"]:
-            print("Completed computation, starting image creation")
-            with open('results.json', 'w', encoding='utf-8') as file_handle:
-                json.dump(all_game_results, file_handle, ensure_ascii=False, indent=4)
+            self.submit_batch_to_worker(batch, handler)
 
-        image_futures = self.client.map(ChessImageGenerator.create_gif, all_game_results)
-        for image_future in as_completed(image_futures):
-            image_data = image_future.result()
-            with open(image_data["filename"], 'wb') as file_handle:
-                file_handle.write(base64.decodebytes(image_data["bytes"]))
-                file_handle.close
-            print("Successfully created: " + image_data["filename"])
+    def submit_batch_to_worker(self, batch, handler):
+        game_futures = self.client.map(ChessDaskCluster.analyse_game_in_worker, batch)
+        for game_future in as_completed(game_futures):
+            game_data = game_future.result()
+            handler(game_data)
